import request from '@/router/axios'
import { getStore } from '@/util/store'

/**
 * 消息上报
 * type	1-通知类型(系统公告类) 2-业务类型(通知反馈类)
 * receiverName	接收者 部门或人员,逗号隔开
 * receiverId	接收者 部门或人员ID，逗号隔开
 * actionTarget	动作目标
 * sendAction	发送动作
 */
 export const addNews = ({ msgType, contentType, receiverName, receiverId, actionTarget, businessId, businessName }) => {
  const user = getStore({ name: 'zzdUserInfo' }) || {}
  const contents = {
    1: `您有一条【${businessName}】的${actionTarget}信息`,
    2: `您有一条【${businessName}】的${actionTarget}信息，请及时处理`
  }
  const params = {
    application: '整体智治线上平台',
    receiverName,
    receiverId,
    actionTarget,
    businessId,
    businessName,
    content: contents[contentType],
    senderId: user.account,
    senderName: user.realName,
    sendAction: `${actionTarget}信息`,
    type: msgType
  }

  console.log('@@@@Params-msg', contentType, params)

  return request({
    url: '/api/system-common/message/save',
    method: 'post',
    data: params
  })
}

/**
 * 处置上报消息参数
 * chanel: 1下发 2上报 3审核通过 4审核退回 5评分 6催办
 */
export const dealReportNewsQuery = async (chanel, row) => {
  let receiverName = ''
  let receiverId = ''
  let contentType = 1
  let msgType = 2
  const targets = {
    1: '待签收',
    2: '待验收',
    3: '已验收通过',
    4: '验收退回',
    5: '已完成评分',
    6: '催办',
    7: '理论成果待审核',
    8: '制度成果待审核',
    9: '理论成果审核通过',
    10: '制度成果审核通过',
    11: '理论成果审核退回',
    12: '制度成果审核退回',
  }

  if (chanel === 1) {
    const { unitName } = row
    const unit = JSON.parse((unitName ||  '[]'))
    receiverName = unit.map(i => i.fullName).join(',')
    receiverId = unit.map(i => i.id).join(',')
  }
  if ([2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12].includes(chanel)) {
    receiverId = row.orgId
    receiverName = row.orgName
  }

  if ([3, 5, 6, 7, 8, 9, 10].includes(chanel)) {
    contentType = 1
  } else {
    contentType = 2
  }

  // return console.log('###Msg', { msgType, contentType, receiverId, receiverName, actionTarget: targets[chanel], businessId: row.id, businessName: row.name });

  addNews({ msgType, contentType, receiverId, receiverName, actionTarget: targets[chanel], businessId: row.id, businessName: row.name })
}
