import request from '@/router/axios'

export const getUserToken = data => {
  return request({
    url: '/api/blade-ztzz/smart/getUserToken',
    method: 'post',
    data
  })
}

export const loginByUsername = (username, password, authorization) =>
  request({
    url: '/api/blade-auth/oauth/token',
    method: 'post',
    headers: {
      Authorization: authorization
    },
    params: {
      tenantId: '330800',
      username: username,
      password: password,
      grant_type: 'password',
      scope: 'all',
      type: 'account'

    }
  })

export const loginBySocial = (tenantId, source, code, state) =>
  request({
    url: '/api/blade-auth/oauth/token',
    method: 'post',
    headers: {
      'Tenant-Id': tenantId
    },
    params: {
      tenantId,
      source,
      code,
      state,
      grant_type: 'social',
      scope: 'all'
    }
  })

/**
 * 使用通过tempToken获取到的token查用户信息
 */
export const getUserInfo = token =>
  request({
    url: '/api/blade-ztzz/smart/getUserInfo',
    method: 'post',
    data: {
      userToken: token
    }
  })

/**
 * 使用用户id查用户信息
 */
 export const getUserByUserId = userId =>
 request({
   url: '/api/blade-user/client/user-info-by-id?userId=' + userId,
   method: 'get',
 })

export const refreshToken = refresh_token =>
  request({
    url: '/api/blade-ztzz/smart/refreshUserToken',
    method: 'post',
    data: {
      userToken: refresh_token
    }
  })

export const registerGuest = (form, oauthId) =>
  request({
    url: '/api/blade-user/register-guest',
    method: 'post',
    params: {
      tenantId: form.tenantId,
      name: form.name,
      account: form.account,
      password: form.password,
      oauthId
    }
  })

export const getCaptcha = () =>
  request({
    url: '/api/blade-auth/oauth/captcha',
    method: 'get'
  })

export const logout = () =>
  request({
    url: '/api/blade-auth/oauth/logout',
    method: 'get'
  })

export const sendLogs = list =>
  request({
    url: '/api/blade-auth/oauth/logout',
    method: 'post',
    data: list
  })

export const clearCache = () =>
  request({
    url: '/api/blade-auth/oauth/clear-cache',
    method: 'get'
  })

export const getUnreadCount = data => {
  return request({
    url: `/api/system-common/message/getUnreadCount?userId=${data.userId}&orgId=${data.orgId}`,
    method: 'post'
  })
}

export const getMessage = data =>
  request({
    url: '/api/system-common/message/page',
    method: 'get',
    params: data
  })

export const clearUnread = data => {
  return request({
    url: `/api/system-common/message/clearUnread?userId=${data.userId}&orgId=${data.orgId}`,
    method: 'post'
  })
}

export const getWindowMessageByUser = data => {
  return request({
    url: '/api/system-common/message/getWindowMessageByUser',
    method: 'get',
    params: data
  })
}

export const Read = data => {
  return request({
    url: '/api/system-common/message/detail',
    method: 'get',
    params: data
  })
}
